<?php

namespace Drupal\Tests\acquia_dam\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test AuthPage controller.
 *
 * @group acquia_dam
 */
class AuthPageTest extends BrowserTestBase {

  /**
   * User that has admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Unauthorized user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $unAuthorizedUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'acquia_dam',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);

    $this->unAuthorizedUser = $this->drupalCreateUser();
  }

  /**
   * Test permission of different users.
   *
   * @throws \Behat\Mink\Exception\ExpectationException
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testAuthPageAccess():void {
    $this->drupalLogin($this->adminUser);
    $session = $this->assertSession();

    $admin_uid = $this->adminUser->id();
    $not_authorized_uid = $this->unAuthorizedUser->id();

    $this->drupalGet("/user/{$admin_uid}/acquia-dam");
    $session->statusCodeEquals(200);

    $this->drupalGet("/user/{$not_authorized_uid}/acquia-dam");
    $session->pageTextContains('Access denied');
    $session->statusCodeEquals(403);

    $this->drupalLogout();
    $this->drupalLogin($this->unAuthorizedUser);

    $this->drupalGet("/user/{$not_authorized_uid}/acquia-dam");
    $session->statusCodeEquals(200);

    $this->drupalGet("/user/{$admin_uid}/acquia-dam");
    $session->pageTextContains('Access denied');
    $session->statusCodeEquals(403);
  }

}
