<?php

namespace Drupal\Tests\acquia_dam\FunctionalJavascript;

use Drupal\acquia_dam\Entity\MediaExpiryDateField;
use Drupal\acquia_dam\Entity\MediaSourceField;
use Drupal\media\Entity\Media;
use Drupal\node\Entity\Node;

/**
 * Test Acquia Dam expiry tag.
 *
 * @group acquia_dam
 */
class AcquiaDamCheckExpireTagTest extends AcquiaDamWebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable';

  /**
   * {@inheritdoc}
   */
  protected function setUp():void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);
  }

  /**
   * Test to check expiry tag on media library field widget.
   */
  public function testExpiryTag() {
    $this->createAndLoginContentCreator();
    $this->grantSiteRegistrationToken();
    $this->grantCurrentUserDamToken();
    $this->createMediaReferenceField();
    $yesterday = \Drupal::time()->getCurrentTime() - 86400;
    $tomorrow = \Drupal::time()->getCurrentTime() + 86400;
    $media_expired = Media::create([
      'bundle' => 'acquia_dam_video_asset',
      MediaSourceField::SOURCE_FIELD_NAME => [
        'asset_id' => 'efb03f75-3c42-497b-baa9-5ec79d1f56af',
      ],
      MediaExpiryDateField::EXPIRY_DATE_FIELD_NAME => [
        'value' => $yesterday,
      ],
    ]);

    $media_expired->save();

    $media = Media::create([
      'bundle' => 'acquia_dam_pdf_asset',
      MediaSourceField::SOURCE_FIELD_NAME => [
        'asset_id' => '0324b0b2-5293-4aa0-b0aa-c85b003395e2',
      ],
      MediaExpiryDateField::EXPIRY_DATE_FIELD_NAME => [
        'value' => $tomorrow,
      ],
    ]);

    $media->save();

    $node = Node::create([
      'type' => 'page',
      'langcode' => 'en',
      'uid' => '0',
      'status' => 1,
      'title' => 'test_expiry',
      'media_field' => [
        ['target_id' => $media_expired->id()],
        ['target_id' => $media->id()],
      ],
    ]);
    $node->save();
    $this->drupalGet("/node/{$node->id()}/edit");
    $modal = $this->assertSession()->waitForElement('css', '.field--name-media-field');

    $expired_items = $modal->findAll('css', '.acquia-dam-expired-asset');
    self::assertCount(1, $expired_items);

    $media_elements = $modal->findAll('css', '.js-media-library-item');
    self::assertCount(2, $media_elements);

    $this->drupalGet('/admin/content/dam-media');
    $modal = $this->assertSession()->waitForElement('css', '.views-element-container');

    $expired_items = $modal->findAll('css', '.acquia-dam-expired-asset');
    self::assertCount(1, $expired_items);

    $media_elements = $modal->findAll('css', 'tr');
    // Including the header.
    self::assertCount(3, $media_elements);
  }

}
