<?php

namespace Drupal\Tests\acquia_dam\FunctionalJavascript;

/**
 * Test Acquia Dam request handling.
 *
 * @group acquia_dam
 */
class AuthPageResponseTest extends AcquiaDamWebDriverTestBase {

  /**
   * User that has admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);
  }

  /**
   * Test how the site handling the errors thrown from the server.
   *
   * @throws \Behat\Mink\Exception\ResponseTextException
   */
  public function testAuthPageResponse():void {
    $this->grantSiteRegistrationToken();
    $this->drupalLogin($this->adminUser);
    $session = $this->assertSession();
    $this->grantDamDomain();

    $this->drupalGet('/acquia-dam/auth', ['query' => ['code' => 'server_error']]);
    $session->pageTextContains('Something went wrong contacting Acquia DAM, and your account can’t be connected. Contact the site administrator.');
    // User authentication.
    $id = $this->adminUser->id();
    $this->drupalGet('/user/acquia-dam/auth', [
      'query' =>
      [
        'uid' => $id,
        'code' => 'pass',
      ],
    ]);
    $session->pageTextContains('Hooray! You can start using media from Acquia DAM');
    // User logout.
    $this->grantCurrentUserDamToken('log_out');
    $this->drupalGet('/user/acquia-dam/logout');
    $session->pageTextContains('Your account has been disconnected from Acquia DAM.');
  }

}
