<?php

declare(strict_types=1);

namespace Drupal\Tests\acquia_dam\FunctionalJavascript;

/**
 * Tests access of the form when the media acquia dam installed.
 *
 * @group acquia_dam
 */
final class MediaAcquiaDamAuth extends AcquiaDamWebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'acquia_dam',
    'acquia_dam_test',
    'media_acquiadam',
  ];

  /**
   * Test user form access and media_acquiadam user state details.
   */
  public function testUserFormCheck() {
    $user = $this->drupalCreateUser([
      'administer site configuration',
    ]);
    $this->drupalLogin($user);
    $this->grantCurrentUserDamToken();
    $current_user_id = $this->loggedInUser->id();
    $this->drupalGet('/user/' . $current_user_id . '/edit');
    $this->assertSession()->pageTextNotContains('Acquia DAM Authorization');
    $user_data = $this->container->get('user.data');
    $media_acquiadam = $user_data->get('media_acquiadam', $current_user_id, 'account');
    $acquia_dam = $user_data->get('acquia_dam', $current_user_id, 'account');
    $this->assertArrayHasKey('acquiadam_username', $media_acquiadam);
    $this->assertArrayHasKey('acquiadam_token', $media_acquiadam);
    $this->assertEquals($acquia_dam['acquia_dam_username'], $media_acquiadam['acquiadam_username']);
    $this->assertEquals($acquia_dam['acquia_dam_token'], $media_acquiadam['acquiadam_token']);
  }

  /**
   * Test config changes in acquia_dam is reflected in media_acquiadam.
   */
  public function testConfigFormCheck() {
    $session = $this->assertSession();
    $user = $this->drupalCreateUser([
      'administer site configuration',
    ]);
    $this->drupalLogin($user);
    $this->grantCurrentUserDamToken();
    $this->drupalGet('/admin/config/acquia-dam');
    $session->pageTextContains('Acquia DAM Configuration');

    self::assertEmpty($this->config('acquia_dam.settings')->get('domain'));
    self::assertEmpty($this->config('media_acquiadam.settings')->get('domain'));

    $this->submitForm(['domain' => 'eudaimonia.widencollective.com'], 'Save DAM configuration');

    $this->assertSession()->waitForText('You can authenticate the site wit Acquia DAM.');
    $this->getSession()->getPage()->hasLink('Authenticate Site');

    self::assertEquals('eudaimonia.widencollective.com', $this->config('acquia_dam.settings')->get('domain'));
    self::assertEquals($this->config('acquia_dam.settings')->get('domain'), $this->config('media_acquiadam.settings')->get('domain'));

  }

}
